@@ -31,6 +31,7 @@
 #include "atimach64accel.h"
 #include "atimach64io.h"
 #include "atixv.h"
+#include "atimach64version.h"
 
 #include <X11/extensions/Xv.h>
 #include "fourcc.h"
@@ -1358,6 +1359,9 @@ ATIMach64XVInitialiseAdaptor
     XF86OffscreenImagePtr surf0 = &(ATIMach64Surface[0]);
     XF86OffscreenImagePtr surf1 = &(ATIMach64Surface[1]);
 
+    if (xf86NameCmp(pScreenInfo->driverName, MACH64_DRIVER_NAME) != 0)
+	return 0;
+
     if (pppAdaptor)
         *pppAdaptor = NULL;
 
@@ -1463,8 +1467,8 @@ ATIMach64XVInitialiseAdaptor
     if (pppAdaptor)
         *pppAdaptor = ppAdaptor;
     else {
-        xfree(ppAdaptor[0]);
-        xfree(ppAdaptor);
+        free(ppAdaptor[0]);
+        free(ppAdaptor);
     }
 
     return 1;
@@ -1501,9 +1505,9 @@ ATIXVFreeAdaptorInfo
         return;
 
     while (nAdaptor > 0)
-        xfree(ppAdaptor[--nAdaptor]);
+        free(ppAdaptor[--nAdaptor]);
 
-    xfree(ppAdaptor);
+    free(ppAdaptor);
 }
 
 /*
@@ -1548,6 +1552,9 @@ ATICloseXVideo
     ATIPtr      pATI
 )
 {
+    if (!pATI->Block1Base)
+        return;
+
     ATIMach64StopVideo(pScreenInfo, pATI, TRUE);
 
     REGION_UNINIT(pScreen, &pATI->VideoClip);
